@@ -15,7 +15,10 @@ import os
 
 
 
-def decompose(signatures, activities, samples,  output, signature_database=None, nnls_add_penalty=0.05, nnls_remove_penalty=0.01, initial_remove_penalty=0.05, de_novo_fit_penalty=0.02, genome_build="GRCh37", refit_denovo_signatures=True, make_decomposition_plots=True, connected_sigs=True, verbose=False):
+def decompose(signatures, activities, samples,  output, signature_database=None, nnls_add_penalty=0.05, 
+              nnls_remove_penalty=0.01, initial_remove_penalty=0.05, de_novo_fit_penalty=0.02, 
+              genome_build="GRCh37", refit_denovo_signatures=True, make_decomposition_plots=True, 
+              collapse_to_SBS96=True,connected_sigs=True, verbose=False, newsignature_threshold=0.8):
 
     
     """
@@ -136,14 +139,14 @@ def decompose(signatures, activities, samples,  output, signature_database=None,
         print ("The {} folder could not be created".format("Decomposed_Solution"))
     
     
-    if processAvg.shape[0]==1536: #collapse the 1596 context into 96 only for the deocmposition 
+    if processAvg.shape[0]==1536 and collapse_to_SBS96==True: #collapse the 1596 context into 96 only for the deocmposition 
         processAvg = pd.DataFrame(processAvg, index=index)
         processAvg = processAvg.groupby(processAvg.index.str[1:8]).sum()
         genomes = genomes.groupby(genomes.index.str[1:8]).sum()
         index = genomes.index
         processAvg = np.array(processAvg)
     
-    if processAvg.shape[0]==288: #collapse the 288 context into 96 only for the deocmposition 
+    if processAvg.shape[0]==288 and collapse_to_SBS96==True: #collapse the 288 context into 96 only for the deocmposition 
         processAvg = pd.DataFrame(processAvg, index=index)
         processAvg = processAvg.groupby(processAvg.index.str[2:9]).sum()
         genomes = pd.DataFrame(genomes, index=index)
@@ -152,7 +155,7 @@ def decompose(signatures, activities, samples,  output, signature_database=None,
         processAvg = np.array(processAvg)
             
     
-    final_signatures = sub.signature_decomposition(processAvg, m, layer_directory2, genome_build=genome_build,signature_database=signature_database, mutation_context=mutation_context, add_penalty=0.05, connected_sigs=connected_sigs,remove_penalty=0.01, make_decomposition_plots=make_decomposition_plots, originalProcessAvg=originalProcessAvg)    
+    final_signatures = sub.signature_decomposition(processAvg, m, layer_directory2, genome_build=genome_build,signature_database=signature_database, mutation_context=mutation_context, add_penalty=0.05, connected_sigs=connected_sigs,remove_penalty=0.01, make_decomposition_plots=make_decomposition_plots, originalProcessAvg=originalProcessAvg,new_signature_thresh_hold = newsignature_threshold)    
     #final_signatures = sub.signature_decomposition(processAvg, m, layer_directory2, genome_build=genome_build)
     # extract the global signatures and new signatures from the final_signatures dictionary
     globalsigs = final_signatures["globalsigs"]
@@ -168,8 +171,13 @@ def decompose(signatures, activities, samples,  output, signature_database=None,
     
     
     
-    result = sub.make_final_solution(processAvg, genomes, allsigids, layer_directory2, m, index, colnames, \
-                            cosmic_sigs=True, attribution = attribution, denovo_exposureAvg  = exposureAvg ,  background_sigs=background_sigs, verbose=verbose, genome_build=genome_build, add_penalty=nnls_add_penalty, remove_penalty=nnls_remove_penalty, initial_remove_penalty=initial_remove_penalty,connected_sigs=connected_sigs,refit_denovo_signatures=False)
+    result = sub.make_final_solution(processAvg, genomes, allsigids, layer_directory2, m, index, colnames, 
+                            cosmic_sigs=True, attribution = attribution, denovo_exposureAvg  = exposureAvg ,  
+                            background_sigs=background_sigs, verbose=verbose, genome_build=genome_build, 
+                            add_penalty=nnls_add_penalty, remove_penalty=nnls_remove_penalty, 
+                            initial_remove_penalty=initial_remove_penalty,connected_sigs=connected_sigs,
+                            collapse_to_SBS96=collapse_to_SBS96,
+                            refit_denovo_signatures=False)
 
     return result
 
